Package 'igraphlayout'

Title: Manual Layout Editor for 'igraph' Objects
Description: Manually edit the layout of 'igraph' objects using an interactive Shiny application. Provides a user-friendly interface to adjust node positions in graph visualizations and apply various layout algorithms from the 'igraph' package with a user-defined seed.
Authors: Mauricio Vargas Sepulveda [aut, cre]
Maintainer: Mauricio Vargas Sepulveda <[email protected]>
License: Apache License (>= 2)
Version: 0.1
Built: 2026-05-08 08:21:21 UTC
Source: https://github.com/pachadotdev/igraphlayout

Help Index


D3 Graph Interactive Widget

Description

Create an interactive D3.js graph visualization

Usage

d3graph(g, width = NULL, height = NULL, elementId = NULL, show_labels = TRUE)

Arguments

g

An igraph object

width

Width of the widget

height

Height of the widget

elementId

Element ID for the widget

show_labels

Logical, whether to show node labels


Shiny bindings for d3graph

Description

Output and render functions for using d3graph within Shiny applications and interactive Rmd documents.

Usage

d3graphOutput(outputId, width = "100%", height = "600px")

renderD3graph(expr, env = parent.frame(), quoted = FALSE)

Arguments

outputId

output variable to read from

width, height

Must be a valid CSS unit (like '100%', '400px', 'auto') or a number, which will be coerced to a string and have 'px' appended.

expr

An expression that generates a d3graph

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.


Edit a Graph Layout Shiny Application

Description

Edit a Graph Layout Shiny Application

Usage

edit_layout(
  g = NULL,
  onStart = NULL,
  options = list(),
  enableBookmarking = NULL,
  uiPattern = "/",
  ...
)

Arguments

g

An igraph object to visualize and edit the layout. If NULL, a random graph will be generated.

onStart

A function that will be called before the app is actually run. This is only needed for shinyAppObj, since in the shinyAppDir case, a global.R file can be used for this purpose.

options

Named options that should be passed to the runApp call (these can be any of the following: "port", "launch.browser", "host", "quiet", "display.mode" and "test.mode"). You can also specify width and height parameters which provide a hint to the embedding environment about the ideal height/width for the app.

enableBookmarking

Can be one of "url", "server", or "disable". The default value, NULL, will respect the setting from any previous calls to enableBookmarking(). See enableBookmarking() for more information on bookmarking your app.

uiPattern

A regular expression that will be applied to each GET request to determine whether the ui should be used to handle the request. Note that the entire request path must match the regular expression in order for the match to be considered successful.

...

arguments to pass to golem_opts. See '?golem::get_golem_options' for more details.