| Title: | Manual Layout Editor for 'igraph' Objects |
|---|---|
| Description: | Manually edit the layout of 'igraph' objects using an interactive Shiny application. Provides a user-friendly interface to adjust node positions in graph visualizations and apply various layout algorithms from the 'igraph' package with a user-defined seed. |
| Authors: | Mauricio Vargas Sepulveda [aut, cre] |
| Maintainer: | Mauricio Vargas Sepulveda <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.1 |
| Built: | 2026-05-08 08:21:21 UTC |
| Source: | https://github.com/pachadotdev/igraphlayout |
Create an interactive D3.js graph visualization
d3graph(g, width = NULL, height = NULL, elementId = NULL, show_labels = TRUE)d3graph(g, width = NULL, height = NULL, elementId = NULL, show_labels = TRUE)
g |
An igraph object |
width |
Width of the widget |
height |
Height of the widget |
elementId |
Element ID for the widget |
show_labels |
Logical, whether to show node labels |
Output and render functions for using d3graph within Shiny applications and interactive Rmd documents.
d3graphOutput(outputId, width = "100%", height = "600px") renderD3graph(expr, env = parent.frame(), quoted = FALSE)d3graphOutput(outputId, width = "100%", height = "600px") renderD3graph(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a d3graph |
env |
The environment in which to evaluate |
quoted |
Is |
Edit a Graph Layout Shiny Application
edit_layout( g = NULL, onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )edit_layout( g = NULL, onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )
g |
An igraph object to visualize and edit the layout. If NULL, a random graph will be generated. |
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |